### Command-line Interface(CLI)
1. Have python 3.7+ installed on your computer
2. Navigate to the directory `cli`
3. Enable `pipenv` in your terminal
```console
> pipenv shell
```
4. Install all needed module for CLI
```console
> pipenv install
```
5. Install CLI package
```console
> python3 setup.py install
```
6. Run CLI 
```console
> dslgtool --qrcode-value {value of QR Code}
```